summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/accountselector.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/ui/accountselector.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/ui/accountselector.h')
-rw-r--r--kopete/libkopete/ui/accountselector.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kopete/libkopete/ui/accountselector.h b/kopete/libkopete/ui/accountselector.h
index c812453d..bdb4c888 100644
--- a/kopete/libkopete/ui/accountselector.h
+++ b/kopete/libkopete/ui/accountselector.h
@@ -28,27 +28,28 @@ class TQListViewItem;
* \brief widget to select an account, based on KListView
* @author Stefan Gehn <metz AT gehn.net>
*/
-class KOPETE_EXPORT AccountSelector : public QWidget
+class KOPETE_EXPORT AccountSelector : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* The parameters @p parent and @p name are handled by
* KListView.
*/
- AccountSelector(TQWidget *parent=0, const char *name=0);
+ AccountSelector(TQWidget *tqparent=0, const char *name=0);
/**
* Constructor for a list of accounts for one protocol only
*
* The parameters @p parent and @p name are handled by
* KListView. @p proto defines the protocol whose accounts are
* shown in the list
*/
- AccountSelector(Kopete::Protocol *proto, TQWidget *parent=0, const char *name=0);
+ AccountSelector(Kopete::Protocol *proto, TQWidget *tqparent=0, const char *name=0);
/**
* Destructor.
@@ -28,27 +28,28 @@ class TQListViewItem;
* Constructor.
*
- * The parameters @p parent and @p name are handled by
+ * The parameters @p tqparent and @p name are handled by
* KListView.
*/
@@ -28,27 +28,28 @@ class TQListViewItem;
* Constructor for a list of accounts for one protocol only
*
- * The parameters @p parent and @p name are handled by
+ * The parameters @p tqparent and @p name are handled by
* KListView. @p proto defines the protocol whose accounts are
* shown in the list